// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "scene/Scene.hpp"
#include "prefabs/SimpleSpinningCubePrefab.hpp"
#include "scene/components/ui/UIImage.hpp"

namespace Dawn {
  class HelloWorldScene : public Scene {
    protected:
      std::shared_ptr<Camera> camera;
      SimpleSpinningCubePrefab *cube;
      std::shared_ptr<UICanvas> canvas;

      void stage() override {
        camera = Camera::create(shared_from_this());
        camera->item->lookAt(glm::vec3(3, 3, 3), glm::vec3(0, 0, 0));

        cube = SimpleSpinningCubePrefab::create(this);

        canvas = UICanvas::create(this);
      }
      
      std::vector<std::shared_ptr<Asset>> getRequiredAssets() override {
        auto game = this->game.lock();
        assertNotNull(game, "Game is null!");
        auto assMan = &game->assetManager;
        std::vector<std::shared_ptr<Asset>> assets;
        vectorAppend(assets, SimpleSpinningCubePrefab::getRequiredAssets(assMan));
        return assets;
      }

    public:
      HelloWorldScene(std::weak_ptr<DawnGame> game) : Scene(game) {}
  };
}